@@ -7,16 +7,17 @@ import org.gnu.gtk.event.FocusListener;
 
 /**
  * FocusListener delegate class.
- *
+ * 
  * @author Tom Ball
  */
 class FocusDelegate extends ListenerDelegate implements FocusListener {
 
-	public FocusDelegate(String signal, Object owner, Method handler, Object target) throws NoSuchMethodException {
-		super(signal, owner, handler, target);
-	}
+    public FocusDelegate(String signal, Object owner, Method handler,
+            Object target) throws NoSuchMethodException {
+        super(signal, owner, handler, target);
+    }
 
-	public boolean focusEvent(FocusEvent event) {
-		return fireEvent(event);
-	}
+    public boolean focusEvent(FocusEvent event) {
+        return fireEvent(event);
+    }
 }
